## Rhodo test

The test requires a data file which was sourced from, https://github.com/lammps/lammps/blob/stable_2Aug2023_update2/bench/data.rhodo.

Checksum: 9b14e259b99b8a28ebbfd86715524c415f82cd5912c164c3827991ac32f23863
